==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/association/impl/ClassAsDerivedOtherSideSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.association.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.association.ClassAsDerivedOtherSide;
import io.ciera.tool.sql.ooaofooa.association.ClassAsDerivedOtherSideSet;
import io.ciera.tool.sql.ooaofooa.association.ClassInAssociationSet;
import io.ciera.tool.sql.ooaofooa.association.DerivedAssociationSet;
import io.ciera.tool.sql.ooaofooa.association.impl.ClassInAssociationSetImpl;
import io.ciera.tool.sql.ooaofooa.association.impl.DerivedAssociationSetImpl;

import java.util.Arrays;
import java.util.List;


public class ClassAsDerivedOtherSideSetImpl extends InstanceSet<ClassAsDerivedOtherSideSet,ClassAsDerivedOtherSide> implements ClassAsDerivedOtherSideSet {

    // attributes
    @Override
    public void setOIR_ID( UniqueId ref_OIR_ID ) throws XtumlException {
        for ( ClassAsDerivedOtherSide classasderivedotherside : this ) classasderivedotherside.setOIR_ID( ref_OIR_ID );
    }
    @Override
    public void setMult( int m_Mult ) throws XtumlException {
        for ( ClassAsDerivedOtherSide classasderivedotherside : this ) classasderivedotherside.setMult( m_Mult );
    }
    @Override
    public void setObj_ID( UniqueId ref_Obj_ID ) throws XtumlException {
        for ( ClassAsDerivedOtherSide classasderivedotherside : this ) classasderivedotherside.setObj_ID( ref_Obj_ID );
    }
    @Override
    public void setRel_ID( UniqueId ref_Rel_ID ) throws XtumlException {
        for ( ClassAsDerivedOtherSide classasderivedotherside : this ) classasderivedotherside.setRel_ID( ref_Rel_ID );
    }
    @Override
    public void setCond( int m_Cond ) throws XtumlException {
        for ( ClassAsDerivedOtherSide classasderivedotherside : this ) classasderivedotherside.setCond( m_Cond );
    }
    @Override
    public void setTxt_Phrs( String m_Txt_Phrs ) throws XtumlException {
        for ( ClassAsDerivedOtherSide classasderivedotherside : this ) classasderivedotherside.setTxt_Phrs( m_Txt_Phrs );
    }


    // selections
    @Override
    public ClassInAssociationSet R203_is_a_ClassInAssociation() throws XtumlException {
        ClassInAssociationSet classinassociationset = new ClassInAssociationSetImpl();
        for ( ClassAsDerivedOtherSide classasderivedotherside : this ) classinassociationset.add( classasderivedotherside.R203_is_a_ClassInAssociation() );
        return classinassociationset;
    }
    @Override
    public DerivedAssociationSet R215_is_related_to_one_side_via_DerivedAssociation() throws XtumlException {
        DerivedAssociationSet derivedassociationset = new DerivedAssociationSetImpl();
        for ( ClassAsDerivedOtherSide classasderivedotherside : this ) derivedassociationset.add( classasderivedotherside.R215_is_related_to_one_side_via_DerivedAssociation() );
        return derivedassociationset;
    }


    @Override
    public ClassAsDerivedOtherSide nullElement() {
        return ClassAsDerivedOtherSideImpl.EMPTY_CLASSASDERIVEDOTHERSIDE;
    }

    @Override
    public ClassAsDerivedOtherSideSet emptySet() {
      return new ClassAsDerivedOtherSideSetImpl();
    }

    @Override
    public ClassAsDerivedOtherSideSet value() {
        return this;
    }

    @Override
    public List<ClassAsDerivedOtherSide> elements() {
        return Arrays.asList(toArray(new ClassAsDerivedOtherSide[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/association/impl/ClassAsDerivedOtherSideSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.association.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.association.ClassAsDerivedOtherSide;
import io.ciera.tool.sql.ooaofooa.association.ClassAsDerivedOtherSideSet;
import io.ciera.tool.sql.ooaofooa.association.ClassInAssociationSet;
import io.ciera.tool.sql.ooaofooa.association.DerivedAssociationSet;
import io.ciera.tool.sql.ooaofooa.association.impl.ClassInAssociationSetImpl;
import io.ciera.tool.sql.ooaofooa.association.impl.DerivedAssociationSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class ClassAsDerivedOtherSideSetImpl extends InstanceSet<ClassAsDerivedOtherSideSet,ClassAsDerivedOtherSide> implements ClassAsDerivedOtherSideSet {

    public ClassAsDerivedOtherSideSetImpl() {
    }

    public ClassAsDerivedOtherSideSetImpl(Comparator<? super ClassAsDerivedOtherSide> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setOIR_ID( UniqueId ref_OIR_ID ) throws XtumlException {
        for ( ClassAsDerivedOtherSide classasderivedotherside : this ) classasderivedotherside.setOIR_ID( ref_OIR_ID );
    }
    @Override
    public void setCond( int m_Cond ) throws XtumlException {
        for ( ClassAsDerivedOtherSide classasderivedotherside : this ) classasderivedotherside.setCond( m_Cond );
    }
    @Override
    public void setObj_ID( UniqueId ref_Obj_ID ) throws XtumlException {
        for ( ClassAsDerivedOtherSide classasderivedotherside : this ) classasderivedotherside.setObj_ID( ref_Obj_ID );
    }
    @Override
    public void setTxt_Phrs( String m_Txt_Phrs ) throws XtumlException {
        for ( ClassAsDerivedOtherSide classasderivedotherside : this ) classasderivedotherside.setTxt_Phrs( m_Txt_Phrs );
    }
    @Override
    public void setMult( int m_Mult ) throws XtumlException {
        for ( ClassAsDerivedOtherSide classasderivedotherside : this ) classasderivedotherside.setMult( m_Mult );
    }
    @Override
    public void setRel_ID( UniqueId ref_Rel_ID ) throws XtumlException {
        for ( ClassAsDerivedOtherSide classasderivedotherside : this ) classasderivedotherside.setRel_ID( ref_Rel_ID );
    }


    // selections
    @Override
    public ClassInAssociationSet R203_is_a_ClassInAssociation() throws XtumlException {
        ClassInAssociationSet classinassociationset = new ClassInAssociationSetImpl();
        for ( ClassAsDerivedOtherSide classasderivedotherside : this ) classinassociationset.add( classasderivedotherside.R203_is_a_ClassInAssociation() );
        return classinassociationset;
    }
    @Override
    public DerivedAssociationSet R215_is_related_to_one_side_via_DerivedAssociation() throws XtumlException {
        DerivedAssociationSet derivedassociationset = new DerivedAssociationSetImpl();
        for ( ClassAsDerivedOtherSide classasderivedotherside : this ) derivedassociationset.add( classasderivedotherside.R215_is_related_to_one_side_via_DerivedAssociation() );
        return derivedassociationset;
    }


    @Override
    public ClassAsDerivedOtherSide nullElement() {
        return ClassAsDerivedOtherSideImpl.EMPTY_CLASSASDERIVEDOTHERSIDE;
    }

    @Override
    public ClassAsDerivedOtherSideSet emptySet() {
      return new ClassAsDerivedOtherSideSetImpl();
    }

    @Override
    public ClassAsDerivedOtherSideSet emptySet(Comparator<? super ClassAsDerivedOtherSide> comp) {
      return new ClassAsDerivedOtherSideSetImpl(comp);
    }

    @Override
    public ClassAsDerivedOtherSideSet value() {
        return this;
    }

    @Override
    public List<ClassAsDerivedOtherSide> elements() {
        return Arrays.asList(toArray(new ClassAsDerivedOtherSide[0]));
    }

}
